@@ -422,31 +422,51 @@ class BaseCST(ABC):
         params: List[cst.Param] = []
 
         for arg in arguments:
-            if arg.get('type') == 'dict':
+            type_ = arg.get('type')
+            if type_:
+                annotation = cst.Annotation(
+                    annotation=cst.Name(arg.get('type')),
+                    whitespace_before_indicator=cst.SimpleWhitespace(value='',)
+                )
+            else:
+                annotation = None
+
+            if type_ == 'dict':
                 default_value = cst.Dict(arg.get('value'))
-            elif arg.get('type') == 'list':
+            elif type_ == 'list':
                 default_value = cst.List(arg.get('value'))
-            elif arg.get('type') == 'tuple':
+            elif type_ == 'tuple':
                 default_value = cst.Tuple(arg.get('value'))
-            elif arg.get('type') == 'float':
+            elif type_ == 'float':
                 default_value = cst.Float(str(arg.get('value')))
-            elif arg.get('type') == 'int':
+            elif type_ == 'int':
                 default_value = cst.Integer(str(arg.get('value')))
             else:  # case of ['bool', 'str']
-                default_value = cst.Name(str(arg.get('value')))
-            params.append(
-                cst.Param(
-                    name=cst.Name(arg.get('name')),
-                    annotation=cst.Annotation(
-                        annotation=cst.Name(arg.get('type')),
-                        whitespace_before_indicator=cst.SimpleWhitespace(value='',)
-                    ),
-                    default=default_value,
-                    star='',
-                    comma=self.default_comma(),
-                    equal=self.default_equal()
-                )
-            )
+                if arg.get('value'):
+                    default_value = cst.Name(str(arg.get('value')))
+                    params.append(
+                        cst.Param(
+                            name=cst.Name(arg.get('name')),
+                            annotation=annotation,
+                            default=default_value,
+                            star='',
+                            comma=self.default_comma(),
+                            equal=self.default_equal()
+                        )
+                    )
+                else:
+                    default_value = None
+                    params.append(
+                        cst.Param(
+                            name=cst.Name(arg.get('name')),
+                            annotation=annotation,
+                            default=default_value,
+                            star='',
+                            comma=cst.MaybeSentinel.DEFAULT,
+                            equal=cst.MaybeSentinel.DEFAULT
+                        )
+                    )
+
         body: List[cst.SimpleStatementLine] = []
         for statement in statements:
             body.append(cst.parse_statement(statement))
